@@ -23,9 +23,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 #define _SN 0x1
 #define _IA_GPU_SN 0x2
 #define _WT 0x2
-
-
-
+#define _L1_WB 0x2
 
 // Cache Policy Definition
 // L3_SCC       : L3 skip caching control (disabled if L3_SCC = 0)
@@ -87,7 +85,7 @@ DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_DYNAMIC_STATE
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_GENERAL_STATE                                    , 1  ,  0   ,      0,   1,        1,      0    , 1      ,  0     );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_GENERAL_STATE_UC                                 , 0  ,  0   ,      0,   1,        1,      0    , 0      ,  0     );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_STATELESS_DATA_PORT                              , 1  ,  0   ,      0,   1,        1,      0    , 1      ,  0     );
-DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_STATELESS_DATA_PORT_L1_CACHED                    , 1  ,  0   ,      0,   1,        0,      0    , 1      ,  0     );
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_STATELESS_DATA_PORT_L1_CACHED                    , 1  ,  0   ,      0,   1,        _L1_WB, 0    , 1      ,  0     );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_INDIRECT_OBJECT                                  , 1  ,  0   ,      0,   1,        1,      0    , 1      ,  0     );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HEAP_INSTRUCTION                                      , 1  ,  0   ,      0,   1,        1,      0    , 1      ,  0     );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_HIZ                                                   , 1  ,  0   ,      0,   1,        1,      0    , 1      ,  0     );
@@ -212,7 +210,7 @@ DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_INTERNAL_READ
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_INTERNAL_WRITE                           , 0   , 0    ,     1,     0,      1,      0,      0,         0        );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_INTERNAL_READ_WRITE_CACHE                , 0   , 0    ,     1,     0,      1,      0,      0,         0        ); 
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_INTERNAL_READ_WRITE_NOCACHE              , 0   , 0    ,     1,     0,      1,      0,      0,         0        );
-DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_OUTPUT_PICTURE                           , 1   , 0    ,     0,     1,      1,      0,      _WT,       0        );
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_OUTPUT_PICTURE                           , 0   , 0    ,     0,     1,      1,      0,      0,         0        );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_OUTPUT_STATISTICS_WRITE                  , 0   , 0    ,     1,     0,      1,      0,      0,        _SN       );  
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DECODE_OUTPUT_STATISTICS_READ_WRITE             , 0   , 0    ,     1,     0,      1,      0,      0,         0        );
 // ENCODE
@@ -234,7 +232,7 @@ DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INTERNAL_READ_FF
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INTERNAL_WRITE_FF                            , 0   , 0    ,     1,     0,      1,      0,      1,       0        );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_FF                       , 0   , 0    ,     1,     0,      1,      0,      1,       0        );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_OUTPUT_PICTURE_FF                            , 1   , 0    ,     0,     1,      1,      0,      _WT,     0        );
-DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INPUT_PICTURE_RENDER                         , 0   , 0    ,     1,     0,      1,      0,      1,       0        );
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INPUT_PICTURE_RENDER                         , 1   , 0    ,     0,     1,      1,      0,      1,       0        );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INPUT_REFERENCE_RENDER                       , 0   , 0    ,     1,     0,      1,      0,      1,       0        );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INTERNAL_READ_RENDER                         , 0   , 0    ,     1,     0,      1,      0,      1,       0        );
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VP_INTERNAL_WRITE_RENDER                        , 1   , 0    ,     0,     1,      1,      0,      1,       0        );
