@@ -48,8 +48,9 @@ namespace GmmLib
         public:
             /* Constructors */
 
-            GmmGen8TextureCalc()
-            {
+            GmmGen8TextureCalc(Context *pGmmLibContext)
+                : GmmGen7TextureCalc(pGmmLibContext)
+	    {
 
             }
 
@@ -72,4 +73,4 @@ namespace GmmLib
             /* inline functions */
     };
 }
-#endif // #ifdef __cplusplus
\ No newline at end of file
+#endif // #ifdef __cplusplus
