@@ -80,8 +80,9 @@ namespace GmmLib
         public:
             /* Constructors */
 
-            GmmGen9TextureCalc()
-            {
+            GmmGen9TextureCalc(Context *pGmmLibContext)
+                : GmmTextureCalc(pGmmLibContext)
+	    {
 
             }
 
@@ -124,4 +125,4 @@ namespace GmmLib
             /* inline functions */
     };
 }
-#endif // #ifdef __cplusplus
\ No newline at end of file
+#endif // #ifdef __cplusplus
