@@ -70,6 +70,7 @@ typedef struct _SKU_FEATURE_TABLE
         unsigned int   FtrCCSNode : 1; // To indicate if CCS Node support is present.
         unsigned int   FtrTileY     : 1;  // Identifies Legacy tiles TileY/Yf/Ys on the platform
         unsigned int   FtrCCSMultiInstance : 1; // To indicate if driver supports MultiContext mode on RCS and more than 1 CCS.
+	unsigned int   FtrL3TransientDataFlush : 1;  // Transient data flush from L3 cache	
     };
 
 
@@ -109,6 +110,12 @@ typedef struct _SKU_FEATURE_TABLE
 	unsigned int   FtrUnified3DMediaCompressionFormats : 1; // DG2 has unified Render/media compression(versus TGLLP/XeHP_SDV 's multiple instances) and requires changes to RC format h/w encodings.
         unsigned int   FtrForceTile4                    : 1;  // Flag to force Tile4 usage as default in Tile64 supported platforms.
         unsigned int   FtrTile64Optimization            : 1;
+        unsigned int   FtrDiscrete                      : 1;  // Discrete-gfx
+        unsigned int   FtrXe2Compression                : 1;  // Xe2 Stateless Compression
+	unsigned int   FtrXe2PlusTiling                 : 1;  // Tile64 MSAA Layout
+        unsigned int   FtrL4Cache                       : 1;  // L4 cache support
+        unsigned int   FtrPml5Support                   : 1;  // xe2 page tables		
+		
     };
 
 
@@ -187,7 +194,6 @@ enum WA_COMPONENT
 typedef struct _WA_TABLE
 {
         // struct wa_3d
-        unsigned int : 0;
 
         WA_DECLARE(
         WaAlignIndexBuffer,
@@ -196,7 +202,7 @@ typedef struct _WA_TABLE
         WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_UNKNOWN)
 
         // struct _wa_Gmm
-        unsigned int : 0;
+        unsigned int Reserved0: 31; // Handle 4bytes alignment boundary to maintain ABI
 
         WA_DECLARE(
         WaValign2ForR8G8B8UINTFormat,
@@ -534,6 +540,36 @@ typedef struct _WA_TABLE
         WA_BUG_TYPE_UNKNOWN,
         WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_UNKNOWN)
 
+        WA_DECLARE(
+        Wa_14018443005,
+        "[Xe2] - Incorrect handling of compression when changing cached PA usage from compression OFF and another client does partial sector compression ON on W with UC",
+        WA_BUG_TYPE_UNKNOWN,
+        WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_GMM)
+
+        WA_DECLARE(
+        Wa_14018976079,
+        "[LNL] CPU-GPU False sharing broken for 1-way coherent pages",
+        WA_BUG_TYPE_UNKNOWN,
+        WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_GMM)
+
+        WA_DECLARE(
+        Wa_14018984349,
+        "[LNL] CPU-GPU False sharing broken for non-coherent pages",
+        WA_BUG_TYPE_UNKNOWN,
+        WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_GMM)
+		
+	WA_DECLARE(
+        Wa_14020040029,
+        "Misalignment on Depth buffer for Zplanes",
+        WA_BUG_TYPE_UNKNOWN,
+        WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_GMM)
+
+        WA_DECLARE(
+        Wa_EmuMufasaSupportOnBmg,
+        "WA for supporting failure seen in BMG with Mufasa",
+        WA_BUG_TYPE_FUNCTIONAL,
+        WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_UNKNOWN)	
+
 } WA_TABLE, *PWA_TABLE;
 
 //********************************** SKU/WA Macros *************************************
